=======
Credits
=======

Maintainer
----------

Full lcls2 daq interface support is maintained at:
* https://github.com/slac-lcls/lcls2

This supports the data acquisition interface for lcls2 at the
SLAC National Accelerator Laboratory.

The primary maintainer for the code packaged here is:
* Chris Ford <caf@slac.stanford.edu>

This recipe is maintained by:
* Zachary Lentz <zlentz@slac.stanford.edu>

Contributors
------------

Interested? See: CONTRIBUTING.rst
